SystemOrganization addCategory: #'Khami-Test-Core'!
SystemOrganization addCategory: #'Khami-Test-Core-Support'!
SystemOrganization addCategory: #'Khami-Test-Utilities'!
SystemOrganization addCategory: #'Khami-Test-Web'!

TestResource subclass: #KmSuspendAutotestResource
	instanceVariableNames: 'autotestState'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmSuspendAutotestResource commentStamp: '<historical>' prior: 0!
TestCases that depend on this resource will prevent Autotest from running while they run.
This is useful for tests that perform any compilation activity which might confuse Autotest.!

!KmSuspendAutotestResource methodsFor: 'as yet unclassified' stamp: 'StuartHerring 4/10/2011 16:02'!
setUp
	autotestState := (Smalltalk at: #AutotestListener 
		ifPresent: [ :c | c allInstances anySatisfy:  [ :l | 
				SystemChangeNotifier uniqueInstance hasNotificationsFor: l]]) 
		ifNil: [false].
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) close ]! !

!KmSuspendAutotestResource methodsFor: 'as yet unclassified' stamp: 'StuartHerring 4/10/2011 13:04'!
tearDown
	autotestState ifTrue: [ (Smalltalk at: #AutotestDashboard) open ]! !

TestRunner subclass: #KmTestRunner
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Utilities'!

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findCategories
	^Smalltalk organization categories select: [ :c | c beginsWith: 'Khami-Test'].! !

!KmTestRunner methodsFor: 'utilities' stamp: 'StuartHerring 2/13/2011 22:30'!
findClassesForCategories: aCollection
	| items |
	aCollection isEmpty
		ifTrue: [ ^ self findClassesForCategories: self findCategories ].
	items := aCollection
		gather: [ :category | 
			((Smalltalk organization listAtCategoryNamed: category) collect: [ :each | Smalltalk globals at: each ])
				select: [ :each | each includesBehavior: self baseClass ] ].
	^ items asSet! !

TestCase subclass: #KmDirectionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeBottom
	self assert: Top equals: Bottom opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeLeft
	self assert: Right equals: Left opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:17'!
testOppositeRight
	self assert: Left equals: Right opposite! !

!KmDirectionTest methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 13:16'!
testOppositeTop
	self assert: Bottom equals: Top opposite! !

TestCase subclass: #KmGameTest
	instanceVariableNames: 'testGame'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:15'!
setUp
	super setUp.
	testGame := KmGame testGame.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 13:31'!
testCallingValidMoveAvailableDoesntChangeRotation
	| game tileSegment |
	game := KmGame tileSet: (KmTileSet buildFromStrings: {'FFFFFFFFF'. 'FFFFVFFFF'}).
	game takeTile.
	tileSegment := game currentTile at: Top.
	game validMoveAvailable.
	self assert: tileSegment equals: (game currentTile at: Top).! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testCurrentTileStartsBlank
	 | game |
	game := testGame.
	self assert: nil equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 16:09'!
testDiscardTile
	| game |
	game := testGame.
	game takeTile.
	game discardTile.
	self assert: nil equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 12:11'!
testNoValidMoveAvailable
	| game |
	game := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'FFFFFFFFF'}).
	game takeTile.
	self deny: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testPlaceTile
	| game gameBoard tile | 
	game := testGame.
	gameBoard := game board.
	tile := game takeTile.
	game placeTileAt: 3 at: 2.
	self assert: tile equals: (gameBoard at: 3 at: 2)! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testPlaceTileClearsCurrentTile
	| game gameBoard tile | 
	game := testGame.
	gameBoard := game board.
	tile := game takeTile.
	game placeTileAt: 1 at: 2.
	self assert: nil equals: game currentTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testPlaceTileWontReplaceExistingTile
	| game gameBoard tile | 
	game := testGame.
	gameBoard := game board.
	tile := game takeTile.
	game placeTileAt: 3 at: 2.
	game placeTileAt: 3 at: 2.
	self assert: tile equals: (gameBoard at: 3 at:2)
! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileSetsCurrentTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game currentTile.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:14'!
testTakeTileTwiceDoesntTakeAdditionalTile
	| game tile |
	game := testGame.
	tile := game takeTile.
	self assert: tile equals: game takeTile! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 13:06'!
testValidMoveAvailable
	| game |
	game := KmGame tileSet: (KmTileSet buildFromStrings: {'FFFFFFFFF'. 'FFFFFFFFF'}).
	game takeTile.
	self assert: game validMoveAvailable.! !

!KmGameTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 13:22'!
testValidMoveAvailableAfterRotation
	| game |
	game := KmGame tileSet: (KmTileSet buildFromStrings: {'VFFFV----'. 'VFFFVFFFF'}).
	game takeTile.
	self assert: game validMoveAvailable.! !

TestCase subclass: #KmSessionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Web'!

!KmSessionTest methodsFor: 'tests' stamp: 'StuartHerring 4/10/2011 22:13'!
testCurrentTileStartsAsNil
	| session |
	session := KmSession new.
	session game: KmGame testGame.
	self assert: session currentTile equals: nil! !

TestCase subclass: #KmTerritoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:00'!
testCompleteVillage
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'VFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFVFFFVFF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryDoesNotHaveAPiece
	self deny: KmTerritory new hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testInitialTerritoryHasZeroPieces
	self assert: 0 equals: KmTerritory new pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testIsComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:46'!
testLoopContentsIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:47'!
testLoopContentsSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: LeftBottom) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:48'!
testLoopIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:49'!
testLoopSegmentIsComplete
	| tiles |
	tiles := {
		'FFFFFF---'. 'FFFFF--F-'. 'FFFF--FF-'. 'FFFF-FF--'.
	} collect: [ :s | KmTile buildFromString: s].
	
	(tiles at: 1) tileAt: Left put: (tiles at: 2).
	(tiles at: 2) tileAt: Bottom put: (tiles at: 3).
	(tiles at: 3) tileAt: Right put: (tiles at: 4).
	(tiles at: 4) tileAt: Top put: (tiles at: 1).
	
	self assert: ((tiles at: 1) at: Left) isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:01'!
testMergeWith
	| s1 s2 |
	s1 := KmFarmRegion inTile: nil.
	s2 := KmFarmRegion inTile: nil.
	s1 territory mergeWith: s2 territory.
	self assert: s2 territory equals: s1 territory! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:03'!
testMergeWithAddsSegments
	| s1 s2 |
	s1 := KmFarmRegion inTile: nil.
	s2 := KmFarmRegion inTile: nil.
	s1 territory mergeWith: s2 territory.
	self assert: 2 equals: s1 territory size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:04'!
testMergeWithRemovesAllSegments
	| s1 s2  territory |
	s1 := KmFarmRegion inTile: nil.
	territory := s1 territory.
	s2 := KmFarmRegion inTile: nil.
	s1 territory mergeWith: s2 territory.
	self assert: territory isEmpty! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:29'!
testMergingTerritoriesWithPiecesGivesSumOfPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	t := s territory.

	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	s territory mergeWith: t.  
	self assert: 2 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testNotComplete
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFF-F-F-'.
	tile1 tileAt: Top put: tile2.
	self deny: (tile1 at: Top) territory isComplete.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:12'!
testTerritoryWithSegmentContainingPieceHasExactlyOnePiece
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: 1 equals: t pieces size.! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:13'!
testTerritoryWithSegmentContainingPieceHasPieces
	| s t |
	s := KmTileSegment fromChar: $F in: nil.
	t := s territory.
	s piece: KmPiece new.
	self assert: t hasPieces! !

!KmTerritoryTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testTilesInSingleTile
	| tile |
	tile := KmTile blank.
	self assert: 1 equals: tile territories any tiles size.! !

TestCase subclass: #KmTestGameBoard
	instanceVariableNames: 'gameBoard'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
setUp
	super setUp.
	gameBoard := KmGameBoard startingTile: KmTile startingTile.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCanPlaceTile
	self assert: (gameBoard canPlaceTile: KmTile blank at: 3 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseAlreadyOccupied
	self deny: (gameBoard canPlaceTile: KmTile blank at: 2 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseDoesntConnect
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 2) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testCantPlaceTileBecauseNotAvailable
	self deny: (gameBoard canPlaceTile: KmTile blank at: 1 at: 1) ! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialColumnsIs3
	self assert: 3 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testInitialRowsIs3
	self assert: 3 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTile
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 3 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:19'!
testPlaceTileAtBottomEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:20'!
testPlaceTileAtLeftEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtLeftEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 2 at: 1 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtRightEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 1 put: tile.
	self assert: 4 equals: gameBoard columns.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoard
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: 4 equals: gameBoard rows.! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileAtTopEdgeExtendsBoardAndRelocates
	 | tile |
	tile := KmTile blank.
	gameBoard at: 1 at: 2 put: tile.
	self assert: tile equals: (gameBoard at: 2 at: 2)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:21'!
testPlaceTileConnectsItToItsNeighbour
	 | tile |
	tile := KmTile blank.
	gameBoard at: 3 at: 2 put: tile.
	self assert: tile equals: ((gameBoard at: 2 at: 2) tileAt: Bottom)! !

!KmTestGameBoard methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 21:18'!
testStartingTileAtCentre
	| board |
	board := gameBoard.
	self assert: board startingTile equals: (board at: 2 at: 2)! !

TestCase subclass: #KmTestGrid
	instanceVariableNames: 'fiveBySeven'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core-Support'!

!KmTestGrid methodsFor: 'running' stamp: 'StuartHerring 1/29/2011 12:42'!
setUp
	fiveBySeven := KmGrid ofSize: 5 by: 7.
	1 to: 5 do: [ :row |
		1 to: 7 do: [ : column | fiveBySeven at: row at: column put: row displayString, 'x', column displayString]] ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:22'!
testAddColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddColumns
	| grid |
	grid := KmGrid new.
	grid addColumns: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:21'!
testAddRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid addRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testAddRows
	| grid |
	grid := KmGrid new.
	grid addRows: 5.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 19:57'!
testAdjacentItems
	self assert: ({'1x2'. '2x3'. '3x2'. '2x1' } hasEqualElements: (fiveBySeven adjacentItemsAt: 2 at: 2))! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridColumns
	self assert: 0 equals: KmGrid new columns ! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testEmptyGridRows
	self assert: 0 equals: KmGrid new rows! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialDataIsNil
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: nil equals: (grid at: 3 at: 4)! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeColumns
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 7 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testInitialSizeRows
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	self assert: 5 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:17'!
testPrependColumn
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependColumn.
	self assert: 8 equals: grid columns.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:14'!
testPrependColumnMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependColumn.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 2 at: 3).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRow
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid prependRow.
	self assert: 6 equals: grid rows.! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/17/2011 11:16'!
testPrependRowMovesItems
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 2 at: 2 put: 'foo'.
	grid prependRow.
	self assert: nil equals: (grid at: 2 at: 2).
	self assert: 'foo' equals: (grid at: 3 at: 2).! !

!KmTestGrid methodsFor: 'tests' stamp: 'StuartHerring 1/12/2011 12:35'!
testPutAndRetrieve
	| grid |
	grid := KmGrid ofSize: 5 by: 7.
	grid at: 3 at: 4 put: 'foo'.
	self assert: 'foo' equals: (grid at: 3 at: 4)! !

TestCase subclass: #KmTileSegmentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:43'!
testBlockerIsIncomplete
	self deny: (KmBlocker inTile: nil) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testCompletingTerritoryCompletesSegment
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'FFFF-FFFF'.
	tile2 := KmTile buildFromString: 'FFFFFF-FF'.
	tile1 tileAt: Top put: tile2.
	self assert: (tile1 at: Top) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testFarmRegionFromCode
	self assert: (KmTileSegment fromChar: $F in: nil) isFarm! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 18:59'!
testInitialSegmentHasNilPiece
	self assert: (KmTileSegment fromChar: $F in: nil) piece isNil! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 18:58'!
testInitialSegmentHasNoPiece
	self deny: (KmTileSegment fromChar: $F in: nil) hasPiece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:04'!
testInitialSegmentIsIncomplete
	self deny: (KmRoadPath inTile: nil) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 4/22/2011 14:03'!
testNewSegmentIsIncomplete
	self deny: (KmFarmRegion inTile: nil) isComplete.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:23'!
testPieceCanNotBePlacedIfSegmentsTerritoryAlreadyHasAPiece
	| s1 s2 t |
	s1 := KmTileSegment fromChar: $F in: nil.
	s2 := KmTileSegment fromChar: $F in: nil.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self deny: s2 canPlacePiece.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:02'!
testPieceIsReturnedProperly
	| s p |
	s := KmTileSegment fromChar: $F in: nil.
	p := KmPiece new.
	s piece: p.
	self assert: p equals: s piece! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:12'!
testPlacementInTileSetsTileAndLocation
	| tile |
	! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:23'!
testPlacingPieceWhenTerritoryAlreadyContainsAPieceThrowsError
	| s1 s2 t |
	s1 := KmTileSegment fromChar: $F in: nil.
	s2 := KmTileSegment fromChar: $F in: nil.
	s1 territory mergeWith: s2 territory.
	s1 piece: KmPiece new.
	self should: [ s2 piece: KmPiece new] raise: Error.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:42'!
testRoadConnectsToRoad
	self assert: ((KmRoadPath inTile: nil) connectsTo:  (KmRoadPath inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:43'!
testRoadDoesntConnectToBlocker
	self deny: ((KmRoadPath inTile: nil) connectsTo:  (KmBlocker inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 13:06'!
testRoadIsPath
	self assert: (KmRoadPath inTile: nil) isPath.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testRoadPathFromCode
	self assert: (KmTileSegment fromChar: $- in: nil) isRoad! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testSegmentLocationAfterRotation
	| tile segment |
	tile := KmTile buildFromString: 'VFFFFFFFF'.
	segment := tile at: Top.
	tile rotate.
	self assert: Right equals: segment location.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 5/9/2011 19:01'!
testSetPieceMeansSegmentHasPiece
	| s |
	s := KmTileSegment fromChar: $F in: nil.
	s piece: KmPiece new.
	self assert: s hasPiece.! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testUnknownCodeThrowsError
	self should: [ KmTileSegment fromChar: $z in: nil ] raise: Error! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:42'!
testVillageConnectsToVillage
	self assert: ((KmVillageRegion inTile: nil) connectsTo:  (KmVillageRegion inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:43'!
testVillageConnectsToWall
	self assert: ((KmVillageRegion inTile: nil) connectsTo:  (KmVillageWall inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:42'!
testVillageDoesntConnectToFarm
	self deny: ((KmVillageRegion inTile: nil) connectsTo:  (KmFarmRegion inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 16:19'!
testVillageRegionFromCode
	self assert: (KmTileSegment fromChar: $V in: nil) isVillage! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:42'!
testWallConnectsToVillage
	self assert: ((KmVillageWall inTile: nil) connectsTo:  (KmVillageRegion inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:42'!
testWallDoesntConnectToFarm
	self deny: ((KmVillageWall inTile: nil) connectsTo:  (KmFarmRegion inTile: nil))! !

!KmTileSegmentTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 12:43'!
testWallDoesntConnectToWall
	self deny: ((KmVillageWall inTile: nil) connectsTo:  (KmVillageWall inTile: nil))! !

TestCase subclass: #KmTileSetCreation
	instanceVariableNames: 'setName className'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetCreation class methodsFor: 'as yet unclassified' stamp: 'StuartHerring 4/10/2011 12:50'!
resources
	^{KmSuspendAutotestResource}! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:17'!
setUp
	super setUp.
	className := #KmTSxxxTestxxx.
	setName := 'xxx Test xxx'.
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:09'!
tearDown
	Smalltalk at: className ifPresent: [ :c | c removeFromSystem ].
! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:09'!
testRegisterTileSetCreatesClass	
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: (Smalltalk globals includesKey: className)! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 21:10'!
testRegisterTileSetCreatesClassIsTileSet
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: KmTileSet equals: (Smalltalk at: className) superclass ! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:04'!
testRegisteredTileSetCanCreateTileSet
	| tileSet |
	KmTileSet register: setName asTileSetUsingStrings: #('FFFFFFFFF').
	tileSet := (Smalltalk at: className) new.
	self assert: 1 equals: tileSet size.! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) tilesetName! !

!KmTileSetCreation methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 22:54'!
testRegisteredTileSetInstanceHasCorrectName
	KmTileSet register: setName asTileSetUsingStrings: {'FFFFFFFFF'}.
	self assert: setName equals: (Smalltalk at: className) new name! !

TestCase subclass: #KmTileSetTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testBuildFromStrings
	| set |
	set := KmTileSet buildFromStrings: #('FFFFFFFFF' 'FFFFFFFFF' 'FFFFFFFFF').
	self assert: 3 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/21/2011 23:05'!
testStartingTileIsFirstInSet
	| set tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	set := KmTileSet buildFromTiles: { tile1. tile2 }.
	self assert: tile1 equals: set takeTile! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:36'!
testTakeTileReducesSize
	| set size |
	set := KmTileSet testSet.
	size := set size.
	set takeTile.
	self assert: size - 1 equals: set size.! !

!KmTileSetTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 20:44'!
testTakeTileRemovesItFromRemaining
	| set tile |
	set := KmTileSet testSet.
	tile := set takeTile.
	self deny: ((set instVarNamed: #tiles) includes: tile)! !

TestCase subclass: #KmTileTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Khami-Test-Core'!

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:33'!
assertMappings: aCollection for: aTile
	self assert: (aCollection allSatisfy: [ :assoc | self verify: assoc key isNumber: assoc value inTile: aTile ]).! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:21'!
testAdjacentVillagesInDifferentTerritories
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Top) territory = (tile at: Right) territory.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTile
	| tile1 |
	tile1 := KmTile startingTile.
	self assert: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalse
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Top)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseDueToPaths
	| tile1 |
	tile1 := KmTile startingTile.
	self deny: (tile1 allowsTile: KmTile blank at: Right)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testAllowsTileReturnsFalseWhenAlreadyOccupied
	| tile1 |
	tile1 := KmTile startingTile.
	tile1 tileAt: Bottom put: KmTile blank.
	self deny: (tile1 allowsTile: KmTile blank at: Bottom)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testBuildFromString
	| tile |
	tile := KmTile buildFromString: 'VFVFF-F--'.
	self assert: (tile at: TopLeft) isVillage.
	self assert: (tile at: TopRight) isVillage.
	self assert: (tile at: RightTop) isFarm.
	self assert: (tile at: RightBottom) isFarm.
	self assert: (tile at: BottomRight) isVillage.
	self assert: (tile at: BottomLeft) isVillage.
	self assert: (tile at: LeftBottom) isFarm.
	self assert: (tile at: LeftTop) isFarm.

	self assert: (tile at: Top) isFarm. 
	self assert: (tile at: Left) isRoad.
	self assert: (tile at: Bottom) isFarm.
	self assert: (tile at: Right) isRoad.
	self assert: (tile at: Centre) isRoad.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/7/2011 15:44'!
testBuildFromStringStopsAtPipe
	| tile |
	tile := KmTile buildFromString: 'FFFFFFFFF|'.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/7/2011 19:57'!
testCrossroadTerritories
	| tile1 |
	tile1 := KmTile buildFromString: 'FFFF----.'.
	self assert: 8 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 5/7/2011 21:02'!
testFarmWithAdjacentVillagesNotComplete
	| tile |
	tile := KmTile buildFromString: 'WWFFVVFFFFFFF'.
	self deny: (tile at: Bottom) territory isComplete ! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:45'!
testInitialPaths
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		Top -> 2.
		CentreTop -> 3.
		Right -> 6.
		CentreRight -> 7.
		Bottom -> 10.
		CentreBottom -> 11.
		Left -> 14.
		CentreLeft -> 15.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:48'!
testInitialRegions
	| tile |
	tile := KmTile blank.
	self assertMappings: {
		TopLeft -> 1. TopRight -> 4.
		RightTop -> 5. RightBottom -> 8.
		BottomRight -> 9. BottomLeft ->12.
		LeftBottom -> 13. LeftTop -> 16} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testNewTileHasNothingAdjacent
	 | tile |
	tile := KmTile blank.
	self assert: nil equals: (tile tileAt: Top).
	self assert: nil equals: (tile tileAt: Right).
	self assert: nil equals: (tile tileAt: Bottom).
	self assert: nil equals: (tile tileAt: Left)! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testNinePartStringSetsCentreLikeEdge
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFF'.
	self assert: (tile at: CentreTop) isRoad.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t2 equals: (t1 tileAt: Top)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:03'!
testPlaceTileSetsReciprocalTile
	 | t1 t2 |
	t1 := KmTile blank.
	t2 := KmTile blank.
	
	t1 tileAt: Top put: t2.
	self assert: t1 equals: (t2 tileAt: Bottom)
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 3/6/2011 13:07'!
testPlacingTileMergesTerritories
	| tile1 tile2 |
	tile1 := KmTile blank.
	tile2 := KmTile blank.
	tile1 tileAt: Left put: tile2.
	self assert: tile1 territories equals: tile2 territories! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:49'!
testRotatedPaths
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		Top -> 14.
		CentreTop -> 15.
		Right -> 2.
		CentreRight -> 3.
		Bottom -> 6.
		CentreBottom -> 7.
		Left -> 10.
		CentreLeft -> 11.
		Centre ->0 } for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/21/2011 12:59'!
testRotatedRegions
	| tile |
	tile := KmTile blank.
	tile rotate.
	self assertMappings: {
		TopLeft -> 13. TopRight -> 16.
		RightTop -> 1. RightBottom -> 4.
		BottomRight -> 5. BottomLeft ->8.
		LeftBottom -> 9. LeftTop -> 12} for: tile.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 1/30/2011 19:23'!
testSimpleTerritories
	| tile1 |
	tile1 := KmTile blank.
	self assert: 1 equals: tile1 territories size.! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 18:23'!
testThirteenPartStringSetsCentreSeparately
	| tile |
	tile := KmTile buildFromString: 'FFFF-FFFFFFFF'.
	self assert: (tile at: CentreTop) isFarm.
! !

!KmTileTest methodsFor: 'tests' stamp: 'StuartHerring 4/27/2011 20:01'!
testWallsOnDifferentTilesStillConnect
	| tile1 tile2 |
	tile1 := KmTile buildFromString: 'WFFFVFFFF'.
	tile2 := KmTile buildFromString: 'FFWFFFVFF'.
	self assert: (tile1 allowsTile: tile2 at: Top)! !

!KmTileTest methodsFor: 'convenience' stamp: 'StuartHerring 1/28/2011 20:34'!
verify: aSymbol isNumber: aNumber inTile: aTile
	^((aTile instVarNamed: #regions) at: aNumber) = (aTile at: aSymbol)! !
